pub(crate) fn panic(info: &PanicInfo<'_>) -> !Expand description
A panic handler is required in Rust, this is probably the most basic one possible
pub(crate) fn panic(info: &PanicInfo<'_>) -> !A panic handler is required in Rust, this is probably the most basic one possible